/*
 * Copyright (c) 1997, 2021 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

@XmlAccessorType(FIELD)
package cardfile;

import jakarta.xml.bind.annotation.XmlAccessorType;
import static jakarta.xml.bind.annotation.XmlAccessType.FIELD; 
